#
# spec file for package cups-backends
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cups-backends
Summary:        Additional Backends for CUPS
License:        GPL-2.0
Group:          Hardware/Printing
Version:        1.1
Release:        5.17
Source0:        pipe
Source1:        http://www.openprinting.org/download/files/beh
Source100:      COPYING
Requires:       cups
# Conflict with foomatic-filters because /usr/lib/cups/backend/beh is provided by it.
# Instead of foomatic-filters now cups-filters-foomatic-rip should be used.
# Because cups-filters-foomatic-rip provides the RPM capability "foomatic-filters"
# there cannot be an unversioned conflict with foomatic-filters here
# (otherwise cups-backends would conflict with cups-filters-foomatic-rip).
# Because cups-filters-foomatic-rip provides at least "foomatic-filters = 4.0.17.256.1"
# (see cups-filters.spec) and because we will not upgrade the foomatic-filters package
# (its current version is 4.0.12) a conflict with foomatic-filters < 4.0.17.256 is used
# to let cups-backends only conflict with the old foomatic-filters package
# but not with the new cups-filters-foomatic-rip package:
Conflicts:      foomatic-filters < 4.0.17.256
# According to RPMLINT:
# "The package should be of the noarch architecture because it doesn't contain any binaries."
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains free additional backends for CUPS.

%prep
# There is nothing to do here because Source0 and Source1 are installed directly from RPM_SOURCE_DIR.

%build
# There is nothing to build because Source0 is a Bash script and Source1 is a Perl script.
# At least test if the syntax is o.k.:
bash -n ${RPM_SOURCE_DIR}/pipe
perl -c ${RPM_SOURCE_DIR}/beh &>/dev/null

%install
mkdir -p $RPM_BUILD_ROOT/usr/lib/cups/backend
# Source0: cups-pipe.sh
install -m 755 ${RPM_SOURCE_DIR}/pipe $RPM_BUILD_ROOT/usr/lib/cups/backend/pipe
# Source1: beh
# Since cups-filters version 1.6.0 the beh backend is provided
# by the cups-filters RPM as /usr/lib/cups/backend/beh which is
# a C re-write of the beh backend written in Perl that is still
# provided here but now named /usr/lib/cups/backend/beh.pl
# to avoid that cups-backends conflicts with cups-filters:
install -m 755 ${RPM_SOURCE_DIR}/beh $RPM_BUILD_ROOT/usr/lib/cups/backend/beh.pl
# Source100: COPYING
install -Dm 644 %{S:100} %{buildroot}%{_docdir}/%{name}/COPYING

%files
%defattr(-,root,root,-)
%dir /usr/lib/cups
%dir /usr/lib/cups/backend
%dir %{_docdir}/%{name}
/usr/lib/cups/backend/pipe
/usr/lib/cups/backend/beh.pl
%{_docdir}/%{name}/COPYING

%changelog
* Thu Mar  9 2017 sfalken@opensuse.org
- Corrected improper source macro for COPYING file.
* Thu Mar  9 2017 sfalken@opensuse.org
- Changed how COPYING is installed.  The %%doc macro is no longer
  properly expanding ${RPM_SOURCE_DIR}, and isn't handling things
  properly with having the COPYING file manually installed in
  this package.   Clears builderror in openSUSE:Factory.
* Thu Mar  3 2016 jsmeix@suse.de
- Since cups-filters version 1.6.0 the beh backend is provided
  by the cups-filters RPM as /usr/lib/cups/backend/beh which is
  a C re-write of the beh backend written in Perl that is still
  provided here but now named /usr/lib/cups/backend/beh.pl
  to avoid that cups-backends conflicts with cups-filters.
* Fri Mar 28 2014 jsmeix@suse.de
- Added 'beh' the Backend Error Handler.
  Since cups-filters version 1.0.42 foomatic-rip's upstream home
  is moved from the foomatic-filters package to cups-filters and
  foomatic-rip is provided in the cups-filters-foomatic-rip RPM.
  The foomatic-filters package also contained 'beh' but that was
  not moved into cups-filters.
  Since hereby /usr/lib/cups/backend/beh is provided by both
  cups-backends and foomatic-filters now cups-backends conflicts
  with foomatic-filters.
  As a result foomatic-filters is now obsolete and
  for foomatic-rip cups-filters-foomatic-rip should be used and
  for 'beh' cups-backends should be used.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Apr  8 2010 jsmeix@suse.de
- Work with upstream compliant CUPS 1.4 on all platforms
  which means to have a fixed "/usr/lib/cups/" directory
  on all platforms (see Novell/Suse Bugzilla bnc#575544).
- Removed the hal backend because HAL is deprecated
  (see Novell/Suse Bugzilla bnc#593946).
- Removed the hpnpf sources because those were "never" built
  (at least not in any of our currently maintained
  products SLES10, 11.0, 11.1, SLES11, and 11.2).
* Thu Aug 27 2009 meissner@suse.de
- fixed as-needed issue by using the right ordering
  'hal.c -o hal -ldbus-1 -lhal' in the spec file
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed via 'export SUSE_ASNEEDED=0'
  for this package as it fails to build with it
* Thu May 28 2009 jsmeix@suse.de
- Removed the beh backend because it is now provided
  in the upgraded foomatic-filters version 4.0.1 package.
- Replaced the pipe backend source cups-pipe.pl perl script
  with a new source cups-pipe.sh bash script which works
  in much better compliance to CUPS and which also fixes
  a bug that it did not get signals from the cupsd
  so that it did not terminate pipe when removing jobs
  (see Novell/Suse Bugzilla bnc#499735).
* Mon Jul 30 2007 crivera@suse.de
- Silence the hal backend.  This will allow current printers
  that use the hal backend to work, but it will not report new
  printers.  This is the first step toward removing the backend
  completely.
* Wed Mar 22 2006 lmuelle@suse.de
- Update beh backend to the current version.
- Add beh documentation derivated from http://www.linuxprinting.org/beh.html.
- Move ncp backend to the ncpfs package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 kssingvo@suse.de
- added backend error handler (beh) (bugzilla#132002)
* Tue Oct  4 2005 jsrain@suse.cz
- fixed the error handling in the pipe backend (#93480)
* Mon Sep 19 2005 lmuelle@suse.de
- Don't redirect stdout to stderr in the pipe backend.
- Install the right files, [#117887].
* Tue Jul 26 2005 kssingvo@suse.de
- initial version
